@@ -45,7 +45,7 @@ The following application events are fired exactly one time at startup in the fo
 .. hint::
     Depending on the used gui framework there can be more app start events. E.g. the :mod:`ae.kivy_app` module fires the
     events `on_app_built` and `on_app_started` (all of them fired after `on_app_run` and `on_app_build`). See also
-    :ref:`kivy app class events`.
+    :ref:`kivy application events`.
 
 
 When an application gets stopped then the following events get fired in the following order:
@@ -353,13 +353,13 @@ are provided by the ae namespace portion :mod:`ae.gui_help`.
 
 The image file resources provided by this portion are taken from:
 
-* :ref:`iconmonstr <https://iconmonstr.com/interface/>`.
+* `iconmonstr <https://iconmonstr.com/interface/>`_.
 
 
 The sound files provides by this portion are taken from:
 
-* :ref:`Erokia <https://freesound.org/people/Erokia/>` at :ref:`freesound.org <https://freesound.org>`.
-* :ref:`plasterbrain <https://freesound.org/people/plasterbrain/>` at :ref:`freesound.org <https://freesound.org>`.
+* `Erokia <https://freesound.org/people/Erokia/>`_ at `freesound.org <https://freesound.org>`_.
+* `plasterbrain <https://freesound.org/people/plasterbrain/>`_ at `freesound.org <https://freesound.org>`_.
 
 """
 import os
@@ -380,7 +380,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.1.62'
+__version__ = '0.1.63'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -846,7 +846,7 @@ class MainAppBase(ConsoleApp, ABC):
         dirty fallback using the inspect module - implemented as method for to allow overwrite in your app project.
 
         :param class_name:      name of the class.
-        :return:                class object with the specified class name or None if not found.
+        :return:                class object with the specified class name or :data:`~ae.base.UNSET` if not found.
         """
         return stack_var(class_name)
 
